import { forwardRef, Input } from '@angular/core';
import { HorizontalAlignment, HorizontalAlignment_$type } from "igniteui-angular-core/ES2015/HorizontalAlignment";
import { VerticalAlignment, VerticalAlignment_$type } from "igniteui-angular-core/ES2015/VerticalAlignment";
import { Visibility, Visibility_$type } from "igniteui-angular-core/ES2015/Visibility";
import { AxisLabelsLocation, AxisLabelsLocation_$type } from "./AxisLabelsLocation";
import { IgxDomainChartComponent } from "./igx-domain-chart-component";
import { brushToString, stringToBrush, ensureBool, ensureEnum } from "igniteui-angular-core/ES2015/componentUtil";
/**
 * Represents a base class for domain charts with X/Y axes
*/
export const IgxXYChartComponent_PROVIDERS = [{ provide: IgxDomainChartComponent, useExisting: forwardRef(() => IgxXYChartComponent) }];
export class IgxXYChartComponent extends IgxDomainChartComponent {
    constructor() {
        super();
    }
    get i() {
        return this._implementation;
    }
    /**
         * Gets or sets function which takes an context object and returns a formatted label for the X-axis.
        *
        * To customize the text of the x-axis label, set `xAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be your data item.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     [xAxisFormatLabel]="formatX"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        */
    get xAxisFormatLabel() {
        return this.i.h9;
    }
    set xAxisFormatLabel(v) {
        this.i.h9 = v;
    }
    /**
         * Gets or sets function which takes a context object and returns a formatted label for the Y-axis.
        *
        * To customize the text of the y-axis label, set `yAxisFormatLabel` to a single-parameter function.  The argument passed to that function will be the numeric value corresponding to a position on the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     [yAxisFormatLabel]="formatY">
        * </igx-category-chart>
        * ```
        */
    get yAxisFormatLabel() {
        return this.i.ia;
    }
    set yAxisFormatLabel(v) {
        this.i.ia = v;
    }
    /**
         * Gets or sets the left margin of labels on the X-axis
        *
        * Use the `xAxisLabelLeftMargin` property to apply a margin left of the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelLeftMargin() {
        return this.i.jo;
    }
    set xAxisLabelLeftMargin(v) {
        this.i.jo = +v;
    }
    /**
         * Gets or sets the top margin of labels on the X-axis
        *
        * Use the `xAxisLabelTopMargin` property to apply a margin above the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelTopMargin() {
        return this.i.jq;
    }
    set xAxisLabelTopMargin(v) {
        this.i.jq = +v;
    }
    /**
         * Gets or sets the right margin of labels on the X-axis
        *
        * Use the `xAxisLabelRightMargin` property to apply a margin right of the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelRightMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelRightMargin() {
        return this.i.jp;
    }
    set xAxisLabelRightMargin(v) {
        this.i.jp = +v;
    }
    /**
         * Gets or sets the bottom margin of labels on the X-axis
        *
        * Use the `xAxisLabelBottomMargin` property to apply a margin below the x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelBottomMargin() {
        return this.i.jn;
    }
    set xAxisLabelBottomMargin(v) {
        this.i.jn = +v;
    }
    /**
         * Gets or sets the left margin of labels on the Y-axis
        *
        * Use the `yAxisLabelLeftMargin` property to apply a margin left of the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelLeftMargin() {
        return this.i.j5;
    }
    set yAxisLabelLeftMargin(v) {
        this.i.j5 = +v;
    }
    /**
         * Gets or sets the top margin of labels on the Y-axis
        *
        * Use the `yAxisLabelTopMargin` property to apply a margin above the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTopMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelTopMargin() {
        return this.i.j7;
    }
    set yAxisLabelTopMargin(v) {
        this.i.j7 = +v;
    }
    /**
         * Gets or sets the right margin of labels on the Y-axis
        *
        * Use the `yAxisLabelRightMargin` property to apply a margin right of the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelRightMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelRightMargin() {
        return this.i.j6;
    }
    set yAxisLabelRightMargin(v) {
        this.i.j6 = +v;
    }
    /**
         * Gets or sets the bottom margin of labels on the Y-axis
        *
        * Use the `yAxisLabelBottomMargin` property to apply a margin below the y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelBottomMargin() {
        return this.i.j4;
    }
    set yAxisLabelBottomMargin(v) {
        this.i.j4 = +v;
    }
    /**
         * Gets or sets color of labels on the X-axis
        *
        * To change the color of x-axis labels, set the `xAxisLabelTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelTextColor="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelTextColor() {
        return brushToString(this.i.nv);
    }
    set xAxisLabelTextColor(v) {
        this.i.nv = stringToBrush(v);
    }
    /**
         * Gets or sets color of labels on the Y-axis
        *
        * To change the color of y-axis labels, set the `yAxisLabelTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTextColor="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelTextColor() {
        return brushToString(this.i.n2);
    }
    set yAxisLabelTextColor(v) {
        this.i.n2 = stringToBrush(v);
    }
    /**
         * Gets or sets the margin around a title on the X-axis
        *
        * Use the `xAxisTitleMargin` property to set a margin around the y-axis title.
        */
    get xAxisTitleMargin() {
        return this.i.jz;
    }
    set xAxisTitleMargin(v) {
        this.i.jz = +v;
    }
    /**
         * Gets or sets the margin around a title on the Y-axis
        *
        * Use the `yAxisTitleMargin` property to set a margin around the y-axis title.
        */
    get yAxisTitleMargin() {
        return this.i.kg;
    }
    set yAxisTitleMargin(v) {
        this.i.kg = +v;
    }
    /**
         * Gets or sets the left margin of a title on the X-axis
        *
        * Use the `xAxisTitleLeftMargin` property to apply a margin left of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="left"
        *     xAxisTitleLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleLeftMargin() {
        return this.i.jy;
    }
    set xAxisTitleLeftMargin(v) {
        this.i.jy = +v;
    }
    /**
         * Gets or sets the left margin of a title on the Y-axis
        *
        * Use the `yAxisTitleLeftMargin` property to apply a margin left of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleLeftMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleLeftMargin() {
        return this.i.kf;
    }
    set yAxisTitleLeftMargin(v) {
        this.i.kf = +v;
    }
    /**
         * Gets or sets the top margin of a title on the X-axis
        *
        * Use the `xAxisTitleTopMargin` property to apply a margin above the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleTopMargin() {
        return this.i.j1;
    }
    set xAxisTitleTopMargin(v) {
        this.i.j1 = +v;
    }
    /**
         * Gets or sets the top margin of a title on the Y-axis
        *
        * Use the `yAxisTitleTopMargin` property to apply a margin above the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="top"
        *     yAxisTitleTopMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleTopMargin() {
        return this.i.ki;
    }
    set yAxisTitleTopMargin(v) {
        this.i.ki = +v;
    }
    /**
         * Gets or sets the right margin of a title on the X-axis
        *
        * Use the `xAxisTitleRightMargin` property to apply a margin right of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="right"
        *     xAxisTitleRightMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleRightMargin() {
        return this.i.j0;
    }
    set xAxisTitleRightMargin(v) {
        this.i.j0 = +v;
    }
    /**
         * Gets or sets the right margin of a title on the Y-axis
        *
        * Use the `yAxisTitleRightMargin` property to apply a margin right of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleRightMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleRightMargin() {
        return this.i.kh;
    }
    set yAxisTitleRightMargin(v) {
        this.i.kh = +v;
    }
    /**
         * Gets or sets the bottom margin of a title on the X-axis
        *
        * Use the `xAxisTitleBottomMargin` property to apply a margin below the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleBottomMargin() {
        return this.i.jx;
    }
    set xAxisTitleBottomMargin(v) {
        this.i.jx = +v;
    }
    /**
         * Gets or sets the bottom margin of a title on the Y-axis
        *
        * Use the `yAxisTitleBottomMargin` property to apply a margin below the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="bottom"
        *     yAxisTitleBottomMargin="100">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleBottomMargin() {
        return this.i.ke;
    }
    set yAxisTitleBottomMargin(v) {
        this.i.ke = +v;
    }
    /**
         * Gets or sets color of title on the X-axis
        *
        * To change the color of the x-axis title, set the `xAxisTitleTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTextColor="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleTextColor() {
        return brushToString(this.i.n1);
    }
    set xAxisTitleTextColor(v) {
        this.i.n1 = stringToBrush(v);
    }
    /**
         * Gets or sets color of title on the Y-axis
        *
        * To change the color of the y-axis title, set the `yAxisTitleTextColor` property to a color string.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleTextColor="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleTextColor() {
        return brushToString(this.i.n8);
    }
    set yAxisTitleTextColor(v) {
        this.i.n8 = stringToBrush(v);
    }
    /**
         * Gets or sets CSS font property for labels on X-axis
        *
        * To change the font of x-axis labels, set the `xAxisLabelTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelTextStyle() {
        return this.i.k4;
    }
    set xAxisLabelTextStyle(v) {
        this.i.k4 = v;
    }
    /**
         * Gets or sets CSS font property for labels on Y-axis
        *
        * To change the font of x-axis labels, set the `yAxisLabelTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelTextStyle() {
        return this.i.l6;
    }
    set yAxisLabelTextStyle(v) {
        this.i.l6 = v;
    }
    /**
         * Gets or sets CSS font property for title on X-axis
        *
        * To change the font of the x-axis title, set the `xAxisTitleTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleTextStyle() {
        return this.i.ls;
    }
    set xAxisTitleTextStyle(v) {
        this.i.ls = v;
    }
    /**
         * Gets or sets CSS font property for title on Y-axis
        *
        * To change the font of the x-axis title, set the `yAxisTitleTextStyle` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="y axis"
        *     yAxisTitleTextStyle="italic 15px arial, sans-serif">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleTextStyle() {
        return this.i.mu;
    }
    set yAxisTitleTextStyle(v) {
        this.i.mu = v;
    }
    /**
         * Gets or sets the format for labels along the X-axis.
        */
    get xAxisLabel() {
        return this.i.kl;
    }
    set xAxisLabel(v) {
        this.i.kl = v;
    }
    /**
         * Gets or sets the property or string from which the labels are derived.
        */
    get yAxisLabel() {
        return this.i.km;
    }
    set yAxisLabel(v) {
        this.i.km = v;
    }
    /**
         * Gets or sets the color to apply to major gridlines along the X-axis.
        *
        * Set `xAxisMajorStroke` to control the color of major gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMajorStroke="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisMajorStroke() {
        return brushToString(this.i.nw);
    }
    set xAxisMajorStroke(v) {
        this.i.nw = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to major gridlines along the Y-axis.
        *
        * Set `yAxisMajorStroke` to control the color of major gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMajorStroke="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisMajorStroke() {
        return brushToString(this.i.n3);
    }
    set yAxisMajorStroke(v) {
        this.i.n3 = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to major gridlines along the X-axis.
        *
        * Set `xAxisMajorStrokeThickness` to control the thickness of major gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMajorStroke="green"
        *     xAxisMajorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get xAxisMajorStrokeThickness() {
        return this.i.jr;
    }
    set xAxisMajorStrokeThickness(v) {
        this.i.jr = +v;
    }
    /**
         * Gets or sets the thickness to apply to major gridlines along the Y-axis.
        *
        * Set `yAxisMajorStrokeThickness` to control the thickness of major gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMajorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get yAxisMajorStrokeThickness() {
        return this.i.j8;
    }
    set yAxisMajorStrokeThickness(v) {
        this.i.j8 = +v;
    }
    /**
         * Gets or sets the thickness to apply to minor gridlines along the X-axis.
        *
        * Set `xAxisMinorStrokeThickness` to control the thickness of minor gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMinorStroke="green"
        *     xAxisMinorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get xAxisMinorStrokeThickness() {
        return this.i.js;
    }
    set xAxisMinorStrokeThickness(v) {
        this.i.js = +v;
    }
    /**
         * Gets or sets the thickness to apply to minor gridlines along the Y-axis.
        *
        * Set `yAxisMinorStrokeThickness` to control the thickness of minor gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMinorStroke="green"
        *     yAxisMinorStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get yAxisMinorStrokeThickness() {
        return this.i.j9;
    }
    set yAxisMinorStrokeThickness(v) {
        this.i.j9 = +v;
    }
    /**
         * Gets or sets the color to apply to stripes along the X-axis.
        *
        * Set `xAxisStrip` to control the alternating color of stripes extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStrip="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisStrip() {
        return brushToString(this.i.ny);
    }
    set xAxisStrip(v) {
        this.i.ny = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to stripes along the Y-axis.
        *
        * Set `yAxisStrip` to control the alternating color of stripes extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStrip="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisStrip() {
        return brushToString(this.i.n5);
    }
    set yAxisStrip(v) {
        this.i.n5 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to the X-axis line.
        *
        * Set `xAxisStroke` to control the color of the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStroke="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisStroke() {
        return brushToString(this.i.nz);
    }
    set xAxisStroke(v) {
        this.i.nz = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to the Y-axis line.
        *
        * Set `yAxisStroke` to control the color of the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStroke="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisStroke() {
        return brushToString(this.i.n6);
    }
    set yAxisStroke(v) {
        this.i.n6 = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to the X-axis line.
        *
        * Set `xAxisStrokeThickness` to control the thickness of the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get xAxisStrokeThickness() {
        return this.i.jt;
    }
    set xAxisStrokeThickness(v) {
        this.i.jt = +v;
    }
    /**
         * Gets or sets the thickness to apply to the Y-axis line.
        *
        * Set `yAxisStrokeThickness` to control the thickness of the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisStroke="green"
        *     yAxisStrokeThickness="3">
        * </igx-category-chart>
        * ```
        */
    get yAxisStrokeThickness() {
        return this.i.ka;
    }
    set yAxisStrokeThickness(v) {
        this.i.ka = +v;
    }
    /**
         * Gets or sets the length of tickmarks along the X-axis.
        *
        * Set `xAxisTickLength` to control the length of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickLength="23">
        * </igx-category-chart>
        * ```
        */
    get xAxisTickLength() {
        return this.i.ju;
    }
    set xAxisTickLength(v) {
        this.i.ju = +v;
    }
    /**
         * Gets or sets the length of tickmarks along the Y-axis.
        *
        * Set `yAxisTickLength` to control the length of tickmarks extending horizontally from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="23">
        * </igx-category-chart>
        * ```
        */
    get yAxisTickLength() {
        return this.i.kb;
    }
    set yAxisTickLength(v) {
        this.i.kb = +v;
    }
    /**
         * Gets or sets the color to apply to tickmarks along the X-axis.
        *
        * Set `xAxisTickStroke` to control the color of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickStroke="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisTickStroke() {
        return brushToString(this.i.n0);
    }
    set xAxisTickStroke(v) {
        this.i.n0 = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to tickmarks along the Y-axis.
        *
        * Set `yAxisTickStroke` to control the color of tickmarks extending horizontally from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="5"
        *     yAxisTickStroke="green">
        * </igx-category-chart>
        * ```
        */
    get yAxisTickStroke() {
        return brushToString(this.i.n7);
    }
    set yAxisTickStroke(v) {
        this.i.n7 = stringToBrush(v);
    }
    /**
         * Gets or sets the thickness to apply to tickmarks along the X-axis.
        *
        * Set `xAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the x-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTickStrokeThickness="10">
        * </igx-category-chart>
        * ```
        */
    get xAxisTickStrokeThickness() {
        return this.i.jv;
    }
    set xAxisTickStrokeThickness(v) {
        this.i.jv = +v;
    }
    /**
         * Gets or sets the thickness to apply to tickmarks along the Y-axis.
        *
        * Set `yAxisTickStrokeThickness` to control the thickness of tickmarks extending vertically from the y-axis line.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTickLength="5"
        *     yAxisTickStrokeThickness="10">
        * </igx-category-chart>
        * ```
        */
    get yAxisTickStrokeThickness() {
        return this.i.kc;
    }
    set yAxisTickStrokeThickness(v) {
        this.i.kc = +v;
    }
    /**
         * Gets or sets the Text to display below the X-axis.
        *
        * Set `xAxisTitle` to display a label adjacent to the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitle() {
        return this.i.lj;
    }
    set xAxisTitle(v) {
        this.i.lj = v;
    }
    /**
         * Gets or sets the Text to display to the left of the Y-axis.
        *
        * Set `yAxisTitle` to display a label adjacent to the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitle() {
        return this.i.ml;
    }
    set yAxisTitle(v) {
        this.i.ml = v;
    }
    /**
         * Gets or sets the color to apply to minor gridlines along the X-axis.
        *
        * Set `xAxisMinorStroke` to control the color of minor gridlines extending vertically from the x-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisMinorStroke="green">
        * </igx-category-chart>
        * ```
        */
    get xAxisMinorStroke() {
        return brushToString(this.i.nx);
    }
    set xAxisMinorStroke(v) {
        this.i.nx = stringToBrush(v);
    }
    /**
         * Gets or sets the color to apply to minor gridlines along the Y-axis.
        *
        * Set `yAxisMinorStroke` to control the color of minor gridlines extending horizontally from the y-axis.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisMinorStroke="green"
        *     yAxisMinorStrokeThickness="1">
        * </igx-category-chart>
        * ```
        */
    get yAxisMinorStroke() {
        return brushToString(this.i.n4);
    }
    set yAxisMinorStroke(v) {
        this.i.n4 = stringToBrush(v);
    }
    /**
         * Gets or sets the angle of rotation for labels along the X-axis.
        *
        * To control the rotation of labels on the x-axis, set the `xAxisLabelAngle` property to a number of rotational degrees.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelAngle="45">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelAngle() {
        return this.i.jm;
    }
    set xAxisLabelAngle(v) {
        this.i.jm = +v;
    }
    /**
         * Gets or sets the angle of rotation for labels along the Y-axis.
        *
        * To control the rotation of labels on the y-axis, set the `yAxisLabelAngle` property to a number of rotational degrees.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelAngle="45">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelAngle() {
        return this.i.j3;
    }
    set yAxisLabelAngle(v) {
        this.i.j3 = +v;
    }
    /**
         * Gets or sets the distance between the X-axis and the bottom of the chart.
        *
        * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        */
    get xAxisExtent() {
        return this.i.jl;
    }
    set xAxisExtent(v) {
        this.i.jl = +v;
    }
    /**
         * Gets or sets the distance between the Y-axis and the left edge of the chart.
        *
        * To allocate space between the x-axis and the edge of the chart, set the `xAxisExtent` property.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250">
        * </igx-category-chart>
        * ```
        */
    get yAxisExtent() {
        return this.i.j2;
    }
    set yAxisExtent(v) {
        this.i.j2 = +v;
    }
    /**
         * Gets or sets the angle of rotation for the X-axis title.
        *
        * Set `xAxisTitleAngle` to control the rotation of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAngle="45">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleAngle() {
        return this.i.jw;
    }
    set xAxisTitleAngle(v) {
        this.i.jw = +v;
    }
    /**
         * Gets or sets the angle of rotation for the Y-axis title.
        *
        * Set `yAxisTitleAngle` to control the rotation of the y-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAngle="45">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleAngle() {
        return this.i.kd;
    }
    set yAxisTitleAngle(v) {
        this.i.kd = +v;
    }
    /**
         * Gets or sets whether to invert the direction of the X-axis by placing the first data items on the right side of the chart.
        *
        * To reverse the direction of items along the x-axis, set the `xAxisInverted` property to true.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisInverted="true">
        * </igx-category-chart>
        * ```
        */
    get xAxisInverted() {
        return this.i.ig;
    }
    set xAxisInverted(v) {
        this.i.ig = ensureBool(v);
    }
    /**
         * Gets or sets whether to invert the direction of the Y-axis by placing the minimum numeric value at the top of the chart.
        *
        * You can use `yAxisInverted` to invert the scale of the y axis like this:
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisInverted="true"
        * >
        *
        * </igx-category-chart>
        * ```
        *
        * The default value of `yAxisInverted` is false.
        */
    get yAxisInverted() {
        return this.i.ih;
    }
    set yAxisInverted(v) {
        this.i.ih = ensureBool(v);
    }
    /**
         * Gets or sets Horizontal alignment of the X-axis title.
        *
        * Set `xAxisTitleAlignment` to control the horizontal alignment of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisTitle="x axis"
        *     xAxisTitleAlignment="right">
        * </igx-category-chart>
        * ```
        */
    get xAxisTitleAlignment() {
        return this.i.nf;
    }
    set xAxisTitleAlignment(v) {
        this.i.nf = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of the Y-axis title.
        *
        * Set `yAxisTitleAlignment` to control the vertical alignment of the x-axis title.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisTitle="y axis"
        *     yAxisTitleAlignment="bottom">
        * </igx-category-chart>
        * ```
        */
    get yAxisTitleAlignment() {
        return this.i.oe;
    }
    set yAxisTitleAlignment(v) {
        this.i.oe = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Horizontal alignment of X-axis labels.
        */
    get xAxisLabelHorizontalAlignment() {
        return this.i.ne;
    }
    set xAxisLabelHorizontalAlignment(v) {
        this.i.ne = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Horizontal alignment of Y-axis labels.
        *
        * Set the `yAxisLabelHorizontalAlignment` property to change the horizontal alignment of y-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisExtent="250"
        *     yAxisLabelHorizontalAlignment="left">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelHorizontalAlignment() {
        return this.i.ng;
    }
    set yAxisLabelHorizontalAlignment(v) {
        this.i.ng = ensureEnum(HorizontalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of X-axis labels.
        *
        * Use the `xAxisLabelVerticalAlignment` property to change the vertical position of x-axis labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisExtent="250"
        *     xAxisLabelVerticalAlignment="bottom">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelVerticalAlignment() {
        return this.i.oc;
    }
    set xAxisLabelVerticalAlignment(v) {
        this.i.oc = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Vertical alignment of Y-axis labels.
        */
    get yAxisLabelVerticalAlignment() {
        return this.i.od;
    }
    set yAxisLabelVerticalAlignment(v) {
        this.i.od = ensureEnum(VerticalAlignment_$type, v);
    }
    /**
         * Gets or sets Visibility of X-axis labels.
        *
        * To hide the x-axis labels, set `xAxisLabelVisibility` to collapsed.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     xAxisLabelVisibility="collapsed">
        * </igx-category-chart>
        * ```
        */
    get xAxisLabelVisibility() {
        return this.i.oh;
    }
    set xAxisLabelVisibility(v) {
        this.i.oh = ensureEnum(Visibility_$type, v);
    }
    /**
         * Gets or sets Visibility of Y-axis labels.
        *
        * To hide the y-axis labels, set `yAxisLabelVisibility` to collapsed.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelVisibility="collapsed">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelVisibility() {
        return this.i.oi;
    }
    set yAxisLabelVisibility(v) {
        this.i.oi = ensureEnum(Visibility_$type, v);
    }
    /**
         * The location of Y-axis labels, relative to the plot area.
        *
        * Set the `yAxisLabelLocation` property to change the location of the y-axis and its labels.
        *
        * ```html
        * <igx-category-chart
        *     [dataSource]="data"
        *     yAxisLabelLocation="outsideRight">
        * </igx-category-chart>
        * ```
        */
    get yAxisLabelLocation() {
        return this.i.ic;
    }
    set yAxisLabelLocation(v) {
        this.i.ic = ensureEnum(AxisLabelsLocation_$type, v);
    }
    /**
         * Called by the UI framework to provide a UI container for rendering this control.
        
        * @param container  * The UI container element.
        */
    provideContainer(container) {
        this.i.provideContainer(container);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The x-coordinate of the location to scale.
        */
    getScaledValueX(unscaledValue) {
        let iv = this.i.jh(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    getUnscaledValueX(scaledValue) {
        let iv = this.i.jj(scaledValue);
        return (iv);
    }
    /**
         * Converts the given visual location to a data value.
        
        * @param unscaledValue  * The y-coordinate of the location to scale.
        */
    getScaledValueY(unscaledValue) {
        let iv = this.i.ji(unscaledValue);
        return (iv);
    }
    /**
         * Converts the given data value to a visual location.
        
        * @param scaledValue  * The data value to un-scale.
        */
    getUnscaledValueY(scaledValue) {
        let iv = this.i.jk(scaledValue);
        return (iv);
    }
}
IgxXYChartComponent.propDecorators = {
    "xAxisFormatLabel": [{ type: Input },],
    "yAxisFormatLabel": [{ type: Input },],
    "xAxisLabelLeftMargin": [{ type: Input },],
    "xAxisLabelTopMargin": [{ type: Input },],
    "xAxisLabelRightMargin": [{ type: Input },],
    "xAxisLabelBottomMargin": [{ type: Input },],
    "yAxisLabelLeftMargin": [{ type: Input },],
    "yAxisLabelTopMargin": [{ type: Input },],
    "yAxisLabelRightMargin": [{ type: Input },],
    "yAxisLabelBottomMargin": [{ type: Input },],
    "xAxisLabelTextColor": [{ type: Input },],
    "yAxisLabelTextColor": [{ type: Input },],
    "xAxisTitleMargin": [{ type: Input },],
    "yAxisTitleMargin": [{ type: Input },],
    "xAxisTitleLeftMargin": [{ type: Input },],
    "yAxisTitleLeftMargin": [{ type: Input },],
    "xAxisTitleTopMargin": [{ type: Input },],
    "yAxisTitleTopMargin": [{ type: Input },],
    "xAxisTitleRightMargin": [{ type: Input },],
    "yAxisTitleRightMargin": [{ type: Input },],
    "xAxisTitleBottomMargin": [{ type: Input },],
    "yAxisTitleBottomMargin": [{ type: Input },],
    "xAxisTitleTextColor": [{ type: Input },],
    "yAxisTitleTextColor": [{ type: Input },],
    "xAxisLabelTextStyle": [{ type: Input },],
    "yAxisLabelTextStyle": [{ type: Input },],
    "xAxisTitleTextStyle": [{ type: Input },],
    "yAxisTitleTextStyle": [{ type: Input },],
    "xAxisLabel": [{ type: Input },],
    "yAxisLabel": [{ type: Input },],
    "xAxisMajorStroke": [{ type: Input },],
    "yAxisMajorStroke": [{ type: Input },],
    "xAxisMajorStrokeThickness": [{ type: Input },],
    "yAxisMajorStrokeThickness": [{ type: Input },],
    "xAxisMinorStrokeThickness": [{ type: Input },],
    "yAxisMinorStrokeThickness": [{ type: Input },],
    "xAxisStrip": [{ type: Input },],
    "yAxisStrip": [{ type: Input },],
    "xAxisStroke": [{ type: Input },],
    "yAxisStroke": [{ type: Input },],
    "xAxisStrokeThickness": [{ type: Input },],
    "yAxisStrokeThickness": [{ type: Input },],
    "xAxisTickLength": [{ type: Input },],
    "yAxisTickLength": [{ type: Input },],
    "xAxisTickStroke": [{ type: Input },],
    "yAxisTickStroke": [{ type: Input },],
    "xAxisTickStrokeThickness": [{ type: Input },],
    "yAxisTickStrokeThickness": [{ type: Input },],
    "xAxisTitle": [{ type: Input },],
    "yAxisTitle": [{ type: Input },],
    "xAxisMinorStroke": [{ type: Input },],
    "yAxisMinorStroke": [{ type: Input },],
    "xAxisLabelAngle": [{ type: Input },],
    "yAxisLabelAngle": [{ type: Input },],
    "xAxisExtent": [{ type: Input },],
    "yAxisExtent": [{ type: Input },],
    "xAxisTitleAngle": [{ type: Input },],
    "yAxisTitleAngle": [{ type: Input },],
    "xAxisInverted": [{ type: Input },],
    "yAxisInverted": [{ type: Input },],
    "xAxisTitleAlignment": [{ type: Input },],
    "yAxisTitleAlignment": [{ type: Input },],
    "xAxisLabelHorizontalAlignment": [{ type: Input },],
    "yAxisLabelHorizontalAlignment": [{ type: Input },],
    "xAxisLabelVerticalAlignment": [{ type: Input },],
    "yAxisLabelVerticalAlignment": [{ type: Input },],
    "xAxisLabelVisibility": [{ type: Input },],
    "yAxisLabelVisibility": [{ type: Input },],
    "yAxisLabelLocation": [{ type: Input },],
};
//# sourceMappingURL=igx-xy-chart-component.js.map