import { Type } from '@angular/core';
import { TimeAxisLabelFormatCollection } from "./igx-time-axis-label-format-collection";
import { IgxCategoryXAxisComponent } from "./igx-category-x-axis-component";
import { IgxAxisComponent } from "./igx-axis-component";
import { OrdinalTimeXAxis } from "./OrdinalTimeXAxis";
/**
 * A horizontal axis that uses an ordinal DateTime scale.
 * On an ordinal time axis, datapoints are aligned according to their order in the ItemsSource, like a category axis.
*
* You can use the `IgxOrdinalTimeXAxisComponent` to display dates at equidistant.
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
*     <igx-ordinal-time-x-axis
* 		dateTimeMemberPath="date"
* 		#xAxis>
*     </igx-ordinal-time-x-axis>
* </igx-data-chart>
* ```
*/
export declare const IgxOrdinalTimeXAxisComponent_PROVIDERS: {
    provide: typeof IgxAxisComponent;
    useExisting: Type<any>;
}[];
export declare class IgxOrdinalTimeXAxisComponent extends IgxCategoryXAxisComponent {
    protected createImplementation(): OrdinalTimeXAxis;
    readonly i: OrdinalTimeXAxis;
    constructor();
    /**
     * Gets or sets the DateTime mapping property for the axis.
    */
    dateTimeMemberPath: string;
    private _labelFormats;
    /**
     * A list of axis label formats to apply, which are selected according to the visible axis range.
     * The label format selected will be the one with the largest range smaller than the visible range of the axis.
    *
    * You can use the `labelFormats` for adjusting the labels depending on the range of the time shown by the chart.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-ordinal-time-x-axis
    * 		[labelFormats]="labelFormats"
    * 		dateTimeMemberPath="time"
    * 		#xAxis>
    *     </igx-ordinal-time-x-axis>
    * </igx-data-chart>
    * ```
    */
    labelFormats: TimeAxisLabelFormatCollection;
    /**
     * Sets the minimum DateTime value to be displayed on this axis.
     * This property can be used to constrain the items displayed on the axis, within the range of DateTimes in the ItemsSource.  It will ignore any setting outside the actual range of data.
    */
    minimumValue: Date;
    /**
     * Sets the maximum DateTime value to be displayed on this axis.
     * This property can be used to constrain the items displayed on the axis, within the range of DateTimes in the ItemsSource.  It will ignore any setting outside the actual range of data.
    */
    maximumValue: Date;
}
