import { EventEmitter, TemplateRef, OnInit } from '@angular/core';
import { Visibility } from "igniteui-angular-core/ES5/Visibility";
import { IgRect } from "igniteui-angular-core/ES5/IgRect";
import { IgPoint } from "igniteui-angular-core/ES5/IgPoint";
import { IgDataTemplate } from "igniteui-angular-core/ES5/IgDataTemplate";
import { TransitionInSpeedType } from './TransitionInSpeedType';
import { SeriesHitTestMode } from './SeriesHitTestMode';
import { IgxAxisComponent } from './igx-axis-component';
import { Series } from './Series';
import { RenderRequestedEventArgs } from './RenderRequestedEventArgs';
export declare const IgxSeriesComponent_PROVIDERS: any[];
/**
 * Represents the base class for all IgxDataChartComponent series.
*/
export declare class IgxSeriesComponent implements OnInit {
    protected _implementation: any;
    readonly i: Series;
    private onImplementationCreated();
    protected createImplementation(): Series;
    constructor();
    readonly seriesInternal: any;
    ngOnInit(): void;
    name: string;
    private _chartLevelData;
    provideData(data: any[]): void;
    private updateDataSource();
    private _dataSource;
    dataSource: any;
    bindAxes(axes: IgxAxisComponent[]): void;
    private _tooltipTemplate;
    private _tooltipContent;
    tooltipTemplate: TemplateRef<any>;
    private _tooltipContainerTemplate;
    tooltipContainerTemplate: TemplateRef<any>;
    private _ensureTooltipCreated(createTooltip, createWrapper);
    private _ensureTooltipDestroyed();
    private _renderer;
    private _provideRenderer(renderer);
    static _createFromInternal(internal: any): IgxSeriesComponent;
    /**
 * Gets whether the series is an annotation layer.
*/
    readonly isAnnotationLayer: boolean;
    /**
     * Gets whether the current series is oriented vertically.
    */
    readonly isVertical: boolean;
    /**
     * Gets whether the current series is a stack fragment.
    */
    readonly isFragment: boolean;
    /**
     * Gets whether the current series shows an area or line shape.
    */
    readonly isAreaOrLine: boolean;
    /**
     * Gets whether the current series is a polar type series.
    */
    readonly isPolar: boolean;
    /**
     * Gets whether the current series is a scatter type series.
    */
    readonly isScatter: boolean;
    /**
     * Gets whether the current series is a radial type series.
    */
    readonly isRadial: boolean;
    /**
     * Gets whether the current series is a stacked type series.
    */
    readonly isStacked: boolean;
    /**
     * Gets whether the current series is a financial type series.
    */
    readonly isFinancial: boolean;
    /**
     * Gets whether the current series is a range type series.
    */
    readonly isRange: boolean;
    /**
     * Gets whether the current series is a category type series.
    */
    readonly isCategory: boolean;
    /**
     * Gets whether the current seires is a geogrpahic series.
    */
    readonly isGeographic: boolean;
    /**
     * Gets whether the default crosshair behavior should be disabled if this series is present.
    *
    * `isDefaultCrosshairBehaviorDisabled` defaults to true for annotation layers. When not using annotaion layers, you can show crosshairs by setting the chart's `IgxSeriesComponent` to true.
    */
    readonly isDefaultCrosshairBehaviorDisabled: boolean;
    /**
     * Gets whether the default tooltip behavior should be disabled if this series is present.
    */
    readonly isDefaultTooltipBehaviorDisabled: boolean;
    /**
     * Returns whether the current series supports visual markers.
    */
    readonly hasMarkers: boolean;
    /**
     * Gets if the series uses an index, which can be used to auto-assign it a color.
    */
    readonly isIndexed: boolean;
    /**
     * Gets if the series should appear in any legends.
    */
    readonly isUsableInLegend: boolean;
    /**
     * Gets or sets the legend item visibility for the current series object.
    *
    * The `IgxSeriesComponent` can be used to exclude only certain `IgxSeriesComponent` from the `IgxSeriesComponent`.
    */
    legendItemVisibility: Visibility;
    /**
     * Gets or sets the LegendItemBadgeTemplate property.
     * The legend item badge is created according to the LegendItemBadgeTemplate on-demand by
     * the series object itself.
    *
    * The `legendItemBadgeTemplate` is used to describe the visual structure of the badge icon for each legend item.
    */
    legendItemBadgeTemplate: IgDataTemplate;
    /**
     * Gets or sets the LegendItemTemplate property.
     * The legend item control content is created according to the LegendItemTemplate on-demand by
     * the series object itself.
    *
    * The `legendItemTemplate` is used to describe the visual structure of each legend item in the `IgxSeriesComponent`.
    */
    legendItemTemplate: IgDataTemplate;
    /**
     * Gets or sets the DiscreteLegendItemTemplate property.
     * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by
     * the series object itself.
    *
    * The legend item control content is created according to the DiscreteLegendItemTemplate on-demand by the series object itself
    */
    discreteLegendItemTemplate: IgDataTemplate;
    /**
     * Gets or sets the easing function used to morph the current series.
    *
    * The `IgxSeriesComponent` and `transitionEasingFunction` can be used to play animation when data is added or removed from a `IgxSeriesComponent`. To play an initial animation see `transitionInDuration`.
    */
    transitionEasingFunction: (time: number) => number;
    /**
     * Gets or sets the EasingFunction used to morph the current series during the initial transition.
    *
    * The `transitionInEasingFunction` can be used with `IgxSeriesComponent` to cofigure the animation when a new datasource is loaded.
    */
    transitionInEasingFunction: (time: number) => number;
    /**
     * Gets or sets the duration of the current series's morph.
    *
    * The `transitionDuration` can be used to play animation when data is added or removed from a `IgxSeriesComponent`. To play an initial animation see `transitionInDuration`.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data"
    *     animateSeriesWhenAxisRangeChanges=true>
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionDuration=500
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    transitionDuration: number;
    /**
     * Gets or sets the current series object's rendering resolution.
    *
    * Setting the `resolution` on a Series to a higher value can help with performance, but it will lower the graphical fidelity of the line. As such, it can be increased up until the fidelity is unacceptable.
    *
    * ```html
    *  <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         resolution=1.5>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    *
    *
    */
    resolution: number;
    /**
     * Gets or sets the Title property.
     * The legend item control is created according to the Title on-demand by
     * the series object itself.
    *
    * The `IgxSeriesComponent` `title` may be used in tooltips and legends.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         showDefaultTooltip="true"
    *         title="InStock Items">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    title: any;
    /**
     * Gets or sets the brush to use for the series.
    *
    * The `brush` along with the `outline` and `IgxSeriesComponent` can be used to affect the visuals of the `IgxSeriesComponent`.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         brush="red">
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    */
    brush: string;
    /**
     * Gets the effective brush for the current series object.
    */
    actualBrush: string;
    /**
     * Gets or sets the brush to use for the outline of the series.
     * Some series types, such as LineSeries, do not display outlines.  Therefore, this property does not affect some charts.
    *
    * The `outline` along with the `brush` and `IgxSeriesComponent` can be used to affect the visuals of the `IgxSeriesComponent`.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         outline="red">
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    */
    outline: string;
    /**
     * Gets the effective outline for the current series object.
    */
    actualOutline: string;
    /**
     * Gets or sets the width of the current series object's line thickness.
    *
    * Depending on the `IgxSeriesComponent` type, this can be the main brush used, or just the outline. For example, when using a `IgxSeriesComponent` it will affect the thickness of the lines drawn, whereas when using a `IgxSeriesComponent` it will affect the outer border thickness of the columns.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         thickness=5>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    */
    thickness: number;
    /**
     * Gets or sets whether highlighting should be enabled for this series, if this type of series supports highlighting.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isHighlightEnabled="true">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    isHighlightingEnabled: boolean;
    /**
     * Gets or sets whether drop shadow should be enabled for this series.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled=true>
    *     </igx-line-series>
    *     </igx-data-chart>
    * ```
    */
    isDropShadowEnabled: boolean;
    /**
     * Gets or sets the shadow blur.
     * This property is ignored when Series.UseSingleShadow is set to true.
    *
    * `shadowBlur` can be set in conjection with `isDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowBlur="7"
    *         shadowColor="blue">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    shadowBlur: number;
    /**
     * Gets or sets the drop shadow color.
    *
    * `shadowColor` can be set in conjection with `isDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowBlur="7"
    *         shadowColor="blue">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    shadowColor: string;
    /**
     * Gets or sets whether drop shadow is applied to the whole series visual or to each of the individual shapes forming the series.
     * When this property is set to true, no Series.ShadowBlur is applied.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled=true
    *         markerType="circle"
    *         useSingleShadow=true>
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    */
    useSingleShadow: boolean;
    /**
     * Gets or sets the drop shadow x-offset.
    *
    * `shadowOffsetX` can be set in conjection with `isDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowOffsetX="10"
    *         shadowOffsetY="10">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    shadowOffsetX: number;
    /**
     * Gets or sets the drop shadow y-offset.
    *
    * `shadowOffsetY` can be set in conjection with `isDropShadowEnabled` to further define the drop shadow effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         isDropShadowEnabled="true"
    *         shadowOffsetX="10"
    *         shadowOffsetY="10">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    shadowOffsetY: number;
    /**
     * Gets or sets the opacity applied to the area fill visual.
     * This property only applies to series that have area visual.
    *
    * ```html
    * <igx-data-chart #chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-area-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         areaFillOpacity=.5>
    *     </igx-area-series>
    * </igx-data-chart>
    * ```
    */
    areaFillOpacity: number;
    /**
     * Gets the actual opacity applied to the area fill visual.
    */
    actualAreaFillOpacity: number;
    /**
     * Gets if the default tooltip has been selected for display.
    *
    * To use the default tooltip set `showDefaultTooltip` to true.
    */
    isDefaultToolTipSelected: boolean;
    /**
     * Gets or sets whether default tooltip will be shown.
    *
    * The default tooltips display all the information relevant to the particular series item (series title, data values, axis values etc.) and are styled to match the series' style. When using default tooltips, you should also set the series `title`.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         showDefaultTooltip="true"
    *         title="InStock Items">
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    showDefaultTooltip: boolean;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    *
    * The `transitionInDuration` can be used with `IgxSeriesComponent` to cofigure the animation when a new datasource is loaded.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionDuration=500
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    transitionInDuration: number;
    /**
     * Gets or sets the duration of the current series's transition in morph.
    *
    * The `transitionInSpeedType` can be used with `IgxSeriesComponent` to cofigure the animation when a new datasource is loaded.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *         #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-column-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         valueMemberPath="value"
    *         transitionInMode="accordionFromBottom"
    *         isTransitionInEnabled=true
    *         transitionInSpeedType="indexScaled"
    *         transitionInDuration=500>
    *     </igx-column-series>
    * </igx-data-chart>
    * ```
    */
    transitionInSpeedType: TransitionInSpeedType;
    /**
     * Gets or sets the whether the chart reacts to mouse move events.
    */
    mouseOverEnabled: boolean;
    /**
     * Gets or sets the coercion methods to use when loading data from data sources.
     * Should be specified before setting any member paths, if being used. Setting it later
     * will not cause data to be reimported into the chart.
    *
    * ```html
    *  <igx-data-chart
    *       [dataSource]="data"
    *      >
    *       <igx-category-x-axis
    *         label="label"
    *         #xAxis>
    *       </igx-category-x-axis>
    *       <igx-numeric-y-axis
    *         #yAxis>
    *       </igx-numeric-y-axis>
    *       <igx-line-series
    *       [xAxis]="xAxis"
    *       [yAxis]="yAxis"
    *       valueMemberPath="value">
    *      </igx-line-series>
    *        <igx-line-series
    *         [xAxis]="xAxis"
    *         [yAxis]="yAxis"
    *         [coercionMethods]= cMethods
    *         valueMemberPath="value!ValueCoercion">
    *        </igx-line-series>
    *     </igx-data-chart>
    * ```
    *
    * &lt;-- position: content member-->
    */
    coercionMethods: any;
    /**
     * Gets or sets whether the series should expect that properties in its items source may be functions that need to be
     * evaluated to yield their value. This defaults to false, as there will be a subtle performance impact to using this feature.
     * This value must be set before assigning an item's source to take effect.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    *     <igx-category-x-axis
    *     label="label"
    *     #xAxis>
    *     </igx-category-x-axis>
    *     <igx-numeric-y-axis
    *     #yAxis>
    *     </igx-numeric-y-axis>
    *     <igx-line-series
    *     [xAxis]="xAxis"
    *     [yAxis]="yAxis"
    *     expectFunctions=true
    *     valueMemberPath="MyFunction">
    *     </igx-line-series>
    * </igx-data-chart>
    * ```
    */
    expectFunctions: boolean;
    /**
     * Method of hit testing to use when pointing to items in this series.
    *
    * The `hitTestMode` can be set to either:
    *
    * -   `IgxSeriesComponent`: automatically decide the appropriate hit test mode for the series.
    * -   `IgxSeriesComponent`: use a color encoded off screen buffer for hit testing. Should always be O(1) time for determining a hit series. This increases frame render time and memory usage, however. Consider using this if hit testing time is degrading performance.
    * -   `IgxSeriesComponent`: use a computational based approach to determine whether the series has been hit. This uses loose bounding boxes, in some cases, and can range in time complexity between O(1) and O(log n) to find a hit. This decreases frame render time compared to color encoded
    */
    hitTestMode: SeriesHitTestMode;
    /**
     * Resolved method of hit testing to use when pointing to items in the chart.
    */
    actualHitTestMode: SeriesHitTestMode;
    /**
     * Overridden by derived series classes to indicate when negative colors are supported or not.
    */
    readonly isNegativeColorSupported: boolean;
    /**
     * Overridden by derived series classes to indicate when markerless display is preferred or not.
    */
    readonly isMarkerlessDisplayPreferred: boolean;
    /**
     * The final value of this series.
    */
    finalValue: number;
    /**
     * The percent change from the beginning to the end of this series.
    */
    percentChange: number;
    /**
 * Gets the brush for tooltip labels.

*/
    resolveTooltipBrush(): string;
    /**
     * Gets the precise item index, if possible, based on the closeness to the previous or next whole integer. If the series cannot provide this information, GetExactItemIndex will return the same integer value as GetItemIndex.
    
    * @param world  * The world position for which to return the index.
    */
    getExactItemIndex(world: IgPoint): number;
    /**
     * Gets the item item index associated with the specified world position
    
    */
    getItemIndex(world: IgPoint): number;
    /**
     * Gets the item that is the best match for the specified world coordinates.
    
    * @param world  * The world coordinates to use.
    */
    getItem(world: IgPoint): any;
    getPreviousOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getNextOrExactIndex(world: IgPoint, skipUnknowns: boolean): number;
    getSeriesValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    /**
     * If possible, will return the best available value bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinate for which to get a value bounding box for
    */
    getSeriesValueBoundingBox(world: IgPoint): IgRect;
    /**
     * If possible, will return the best available value marker bounding box within the series that has the best value match for the world position provided.
    
    * @param world  * The world coordinates for which to get a value marker bounding box for
    */
    getSeriesValueMarkerBoundingBox(world: IgPoint): IgRect;
    getSeriesHighValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesHighValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesLowValue(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    getSeriesLowValuePosition(world: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValuePositionFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): IgPoint;
    getSeriesValueFromSeriesPixel(mouse: IgPoint, useInterpolation: boolean, skipUnknowns: boolean): number;
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan(): number;
    /**
     * Converts a point from coordinates within the series plot area to a world position within axis space.
    
    * @param seriesPoint  * The pixel location within the plot area of the series.
    */
    toWorldPosition(seriesPoint: IgPoint): IgPoint;
    /**
     * Converts a point from world coordinates to coordinates within the viewport of the series.
    
    * @param world  * The world position from which to convert.
    */
    fromWorldPosition(world: IgPoint): IgPoint;
    /**
     * Requests that the provided item should be brought into view if possible.
    
    * @param item  * The item to attempt to bring into view.
    */
    scrollIntoView(item: any): boolean;
    /**
     * Renders the series.
    
    * @param animate  * True if the change should be animated.
    */
    renderSeries(animate: boolean): void;
    /**
     * Gets the effective viewport, adjusted to account for margins and other factors.
    
    */
    getEffectiveViewport(): IgRect;
    /**
     * Removes all alternate views of this series.
    
    */
    removeAllAlternateViews(): void;
    /**
     * Removes an alternate view of this series.
    
    * @param viewIdentifier  * The string identifier for the view to remove.
    */
    removeAlternateView(viewIdentifier: string): void;
    /**
     * Replays the assigned transition in animation, if any.
    
    */
    replayTransitionIn(): void;
    /**
     * Simulates a pointer hover over the series surface.
    
    * @param point  * The pointer position relative to the series viewport over which to hover.
    *
    * When tooltips are enabled, `simulateHover` can be used to automatically display the tooltip over a particular series item.
    */
    simulateHover(point: IgPoint): void;
    /**
     * Called when this series' Style is updated.
    
    */
    styleUpdated(): void;
    setNegativeColors(negativeBrush: string, negativeOutline: string): void;
    /**
     * Moves the cursor point to the provided world position. Some series may react to the current cursor position.
    
    * @param point  * The cursor point, in world coordinates.
    *
    * `moveCursorPoint` can be used on annotation layers to programitically show the annotation at the given point.
    */
    moveCursorPoint(point: IgPoint): void;
    private _renderRequested;
    /**
     * This event is raised every time a render has been requested from a series.
    */
    readonly renderRequested: EventEmitter<{
        sender: any;
        args: RenderRequestedEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
}
